@@ -30,5 +30,7 @@ class BaseTable:
                 values = [dict([(k, v) for k, v in item.items() if k in cols]) for item in values]
             elif isinstance(values[0], list):
                 values = [dict(zip(keys, item)) for item in values]
-        ins = self.table.insert(values=values).prefix_with("OR REPLACE")
+        # ins = self.table.insert(values=values).prefix_with("OR REPLACE")
+        ins = self.table.insert(values=values)
+        ins = ins.on_duplicate_key_update(data=ins.inserted.data, status='U')
         engine.execute(ins)
