@@ -29,7 +29,7 @@ class LoadDataKline:
         timedelta = limit * timeframe_duration_in_ms
         result_dictionary = {}
 
-        for _ in tqdm(10000):
+        for _ in tqdm(range(10000)):
             fetch_since = earliest_timestamp - timedelta
             result = self.exchange.fetch_ohlcv(symbol, timeframe, fetch_since, limit)
 
